@@ -1,6 +1,7 @@
 from services.add_action import action_create
 from shared_info.constants import ERROR_PNG
 import PySimpleGUI as sg
+from services.object_collections_to_string import convert_collection_to_string_using_method
 
 
 def add_action(window, values, todo_actions, current_tags, saved_actions):
@@ -28,8 +29,5 @@ def add_action(window, values, todo_actions, current_tags, saved_actions):
         return
 
     todo_actions.append(new_action)
-    window['-ACTION-LIST-'].update(create_todo_actions_for_listbox(todo_actions))
-
-
-def create_todo_actions_for_listbox(todo_actions):
-    return list(map(lambda obj: obj.format_for_todo_listbox(), todo_actions))
+    window['-ACTION-LIST-'].update(convert_collection_to_string_using_method(collection=todo_actions,
+                                                                             method_name='format_for_todo_listbox'))
